function SRMRval  = main(wav_Filename)
% This function computes the adaptive speech-to-reverberation modulation energy ratio
% measure (SRMR), as described in Falk and Chan, IWAENC 2008. The program operates on 8kHz 
% or 16kHz sampled speech files (algorithm not tested for audio/music files). 
%
% The software is provided as is for research purposes and without
% warranty of any kind.
% Author: T. H. Falk
% Release Date: November 10, 2008
% Version: v1.0
% Acknowledgements: Thanks to Mrs. Lu Huo for providing Matlab versions of the ITU-T P.56
% speech voltmeter. The gammatone filterbank design uses Malcolm Slaney's Auditory 
% Matlab toolbox; the necessary files are included in the auditory directory. 
% Note that the Matlab Signal Processing Toolbox may be needed in order to run the 
% main SRMR script. 
%
% Please send comments to t_falk@hotmail.com.

addpath auditory
addpath vad
addpath PreProc

%%% Pre-Processing
% read the .wav file
[smpl,fs,nbits]=wavread(wav_Filename);

% test for valid sampling frequency
if ne(fs, 8000) && ne(fs,16000)
    error('myToolbox:myFunction:fsNotSupported','Error, sampling frequency must be either 8kHz or 16kHz');
    pause; disp('Press Ctrl+C to exit');
end

%%--------------------
%%Uncomment this part to dowsample speech files from 16kHz to 8kHz sampling
%%rate
%if fs==16000
%    smpl = resample(smpl, 1, 2);
%    fs=8000
%end
%%---------------------

% Simple energy-thresholding voice activity detection. A more advanced VAD
% should be used with noise-corrupted speech files
smpl_vad = vad_s(smpl, fs);

% ITU-T P.56 energy normalization to -26dBov
input=asl_adjust(smpl_vad,fs,-26);

% SRMR computation 
SRMRval = SRMR(input,fs);
